@@ -15,7 +15,7 @@ use Filter::signatures;
 use feature 'signatures';
 no warnings 'experimental::signatures';
 
-our $VERSION = '0.41';
+our $VERSION = '0.42';
 
 =head1 NAME
 
@@ -182,11 +182,6 @@ sub new( $class, %options ) {
         shift @$cmd;
     };
 
-    for (@$cmd) {
-        $_ = '--next'
-            if $_ eq '-:'; # GetOptions does not like "next|:" as specification
-    };
-
     my $p = Getopt::Long::Parser->new(
         config => [ 'bundling', 'no_auto_abbrev', 'no_ignore_case_always' ],
     );
@@ -285,18 +280,26 @@ sub _build_request( $self, $uri, $options, %build_options ) {
     my $body;
 
     my @headers = @{ $options->{header} || []};
-    my $method = $options->{request};
+    my $method = $options->{method};
 
     # Ideally, we shouldn't sort the data but process it in-order
     my @post_raw_data;
     if( exists $options->{ 'post-data' }) {
         @post_raw_data = $options->{'post-data'};
         $method = 'POST';
+    };
+    if( exists $options->{ 'body-data' }) {
+        @post_raw_data = $options->{'body-data'};
+        $method ||= 'POST';
     };
                     ;
     if( my $file = $options->{'post-file'} ) {
         @post_raw_data = $self->_maybe_read_data_file( $build_options{ read_files }, $file );
         $method = 'POST';
+    };
+    if( my $file = $options->{'body-file'} ) {
+        @post_raw_data = $self->_maybe_read_data_file( $build_options{ read_files }, $file );
+        $method ||= 'POST';
     };
                     ;
     my @form_args = @{ $options->{form} || []};
@@ -325,7 +328,7 @@ sub _build_request( $self, $uri, $options, %build_options ) {
         };
 
         if( @form_args) {
-            $method = 'POST';
+            $method ||= 'POST';
 
             my $req = HTTP::Request::Common::POST(
                 'https://example.com',
@@ -336,7 +339,7 @@ sub _build_request( $self, $uri, $options, %build_options ) {
             $request_default_headers{ 'Content-Type' } = join "; ", $req->headers->content_type;
 
         } elsif( defined $data ) {
-            $method = 'POST';
+            $method ||= 'POST';
             $body = $data;
             $request_default_headers{ 'Content-Type' } = 'application/x-www-form-urlencoded';
 
